@@ -22,11 +22,11 @@ from requests.auth import AuthBase
 class TokenAuth(AuthBase):
     """AuthBase override for bearer token based auth."""
 
-    def __init__(self: "TokenAuth", token: str) -> None:
+    def __init__(self, token: str) -> None:
         """Create an AuthBase for the specified bearer auth token."""
         self._token = token
 
-    def __call__(self: "TokenAuth", r: models.PreparedRequest) -> models.PreparedRequest:
+    def __call__(self, r: models.PreparedRequest) -> models.PreparedRequest:
         """Append Auth Header to request."""
         r.headers["Authorization"] = "Bearer {}".format(self._token)
         return r
